==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_entities/assetequipment_001/AssetDependency.java <==

package net.datastream.schemas.mp_entities.assetequipment_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ASSETPARENT_Type;
import net.datastream.schemas.mp_fields.POSITIONPARENT_Type;
import net.datastream.schemas.mp_fields.SYSTEMPARENT_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPENDENTASSET"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONDEPENDENTPOSITION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONDEPENDENTPRIMARYSYSTEM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONDEPENDENTSYSTEM" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "dependentasset",
    "nondependentposition",
    "nondependentprimarysystem",
    "nondependentsystem"
})
@XmlRootElement(name = "AssetDependency")
public class AssetDependency {

    @XmlElement(name = "DEPENDENTASSET", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ASSETPARENT_Type dependentasset;
    @XmlElement(name = "NONDEPENDENTPOSITION", namespace = "http://schemas.datastream.net/MP_fields")
    protected POSITIONPARENT_Type nondependentposition;
    @XmlElement(name = "NONDEPENDENTPRIMARYSYSTEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected SYSTEMPARENT_Type nondependentprimarysystem;
    @XmlElement(name = "NONDEPENDENTSYSTEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected List<SYSTEMPARENT_Type> nondependentsystem;

    /**
     * Gets the value of the dependentasset property.
     * 
     * @return
     *     possible object is
     *     {@link ASSETPARENT_Type }
     *     
     */
    public ASSETPARENT_Type getDEPENDENTASSET() {
        return dependentasset;
    }

    /**
     * Sets the value of the dependentasset property.
     * 
     * @param value
     *     allowed object is
     *     {@link ASSETPARENT_Type }
     *     
     */
    public void setDEPENDENTASSET(ASSETPARENT_Type value) {
        this.dependentasset = value;
    }

    /**
     * Gets the value of the nondependentposition property.
     * 
     * @return
     *     possible object is
     *     {@link POSITIONPARENT_Type }
     *     
     */
    public POSITIONPARENT_Type getNONDEPENDENTPOSITION() {
        return nondependentposition;
    }

    /**
     * Sets the value of the nondependentposition property.
     * 
     * @param value
     *     allowed object is
     *     {@link POSITIONPARENT_Type }
     *     
     */
    public void setNONDEPENDENTPOSITION(POSITIONPARENT_Type value) {
        this.nondependentposition = value;
    }

    /**
     * Gets the value of the nondependentprimarysystem property.
     * 
     * @return
     *     possible object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public SYSTEMPARENT_Type getNONDEPENDENTPRIMARYSYSTEM() {
        return nondependentprimarysystem;
    }

    /**
     * Sets the value of the nondependentprimarysystem property.
     * 
     * @param value
     *     allowed object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public void setNONDEPENDENTPRIMARYSYSTEM(SYSTEMPARENT_Type value) {
        this.nondependentprimarysystem = value;
    }

    /**
     * Gets the value of the nondependentsystem property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nondependentsystem property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNONDEPENDENTSYSTEM().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link SYSTEMPARENT_Type }
     * 
     * 
     */
    public List<SYSTEMPARENT_Type> getNONDEPENDENTSYSTEM() {
        if (nondependentsystem == null) {
            nondependentsystem = new ArrayList<SYSTEMPARENT_Type>();
        }
        return this.nondependentsystem;
    }

}

==> eam-wshub-proxyclient-11.4-10-sources.jar: net/datastream/schemas/mp_entities/assetequipment_001/AssetDependency.java <==

package net.datastream.schemas.mp_entities.assetequipment_001;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ASSETPARENT_Type;
import net.datastream.schemas.mp_fields.POSITIONPARENT_Type;
import net.datastream.schemas.mp_fields.SYSTEMPARENT_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPENDENTASSET"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONDEPENDENTPOSITION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONDEPENDENTPRIMARYSYSTEM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONDEPENDENTSYSTEM" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "dependentasset",
    "nondependentposition",
    "nondependentprimarysystem",
    "nondependentsystem"
})
@XmlRootElement(name = "AssetDependency")
public class AssetDependency {

    @XmlElement(name = "DEPENDENTASSET", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected ASSETPARENT_Type dependentasset;
    @XmlElement(name = "NONDEPENDENTPOSITION", namespace = "http://schemas.datastream.net/MP_fields")
    protected POSITIONPARENT_Type nondependentposition;
    @XmlElement(name = "NONDEPENDENTPRIMARYSYSTEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected SYSTEMPARENT_Type nondependentprimarysystem;
    @XmlElement(name = "NONDEPENDENTSYSTEM", namespace = "http://schemas.datastream.net/MP_fields")
    protected List<SYSTEMPARENT_Type> nondependentsystem;

    /**
     * Obtient la valeur de la propriété dependentasset.
     * 
     * @return
     *     possible object is
     *     {@link ASSETPARENT_Type }
     *     
     */
    public ASSETPARENT_Type getDEPENDENTASSET() {
        return dependentasset;
    }

    /**
     * Définit la valeur de la propriété dependentasset.
     * 
     * @param value
     *     allowed object is
     *     {@link ASSETPARENT_Type }
     *     
     */
    public void setDEPENDENTASSET(ASSETPARENT_Type value) {
        this.dependentasset = value;
    }

    /**
     * Obtient la valeur de la propriété nondependentposition.
     * 
     * @return
     *     possible object is
     *     {@link POSITIONPARENT_Type }
     *     
     */
    public POSITIONPARENT_Type getNONDEPENDENTPOSITION() {
        return nondependentposition;
    }

    /**
     * Définit la valeur de la propriété nondependentposition.
     * 
     * @param value
     *     allowed object is
     *     {@link POSITIONPARENT_Type }
     *     
     */
    public void setNONDEPENDENTPOSITION(POSITIONPARENT_Type value) {
        this.nondependentposition = value;
    }

    /**
     * Obtient la valeur de la propriété nondependentprimarysystem.
     * 
     * @return
     *     possible object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public SYSTEMPARENT_Type getNONDEPENDENTPRIMARYSYSTEM() {
        return nondependentprimarysystem;
    }

    /**
     * Définit la valeur de la propriété nondependentprimarysystem.
     * 
     * @param value
     *     allowed object is
     *     {@link SYSTEMPARENT_Type }
     *     
     */
    public void setNONDEPENDENTPRIMARYSYSTEM(SYSTEMPARENT_Type value) {
        this.nondependentprimarysystem = value;
    }

    /**
     * Gets the value of the nondependentsystem property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nondependentsystem property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNONDEPENDENTSYSTEM().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link SYSTEMPARENT_Type }
     * 
     * 
     */
    public List<SYSTEMPARENT_Type> getNONDEPENDENTSYSTEM() {
        if (nondependentsystem == null) {
            nondependentsystem = new ArrayList<SYSTEMPARENT_Type>();
        }
        return this.nondependentsystem;
    }

}
